==> v4_navigation_engine-0.1.62.tar.gz: ios/Classes/NavigationV4 (1)/Models/PointOfInterest.swift <==
//
//  PointOfInterest.swift
//  NavigationUI
//
//  Created by Hassine on 17/06/2020.
//  Copyright © 2020 com.mile. All rights reserved.
//


import Foundation
import CoreLocation
//import Firebase
//import FirebaseFirestore




public struct PointOfInterest  {
    public var statusDB: Int = 0 // status Data base
    
    
    public var route: RouteInformation?
    public var key: String
    
    
    
    public var description: String? {
        get {
            return MyUtils.translateToSelectedLanguage(en: descriptionEn, fr: descriptionFr, es: descriptionEs, it: descriptionIt, de: descriptionDe, nl: descriptionNl, pt: descriptionPt)
        }
    }
    
    public var vocal: String? {
        get {
            return MyUtils.translateToSelectedLanguage(en: vocalEn, fr: vocalFr, es: vocalEs, it: vocalIt, de: vocalDe, nl: vocalNl, pt: vocalPt)
        }
    }
    
    public  var name: String {
        get {
            return MyUtils.translateToSelectedLanguage(en: nameEn, fr: nameFr, es: nameEs, it: nameIt, de: nameDe, nl: nameNl, pt: namePt) ?? "error"
        }
    }
    
    
    public var question: String? {
        get {
            if "fr" == MyUtils.getLanguageISO()
            {
                return questionFr
            }
            else
            {
                return questionEn
            }
        }
    }
    
    public  var answer: String? {
        get {
            if "fr" == MyUtils.getLanguageISO()
            {
                return answerFr
            }
            else
            {
                return answerEn
            }
        }
    }
    
    
    public  var indice: String? {
        get {
            if "fr" == MyUtils.getLanguageISO()
            {
                return indiceFr
            }
            else
            {
                return indiceEn
            }
        }
    }
    
    
    public  var instruction: String? {
        get {
            if "fr" == MyUtils.getLanguageISO()
            {
                return instructionFr
            }
            else
            {
                return instructionEn
            }
        }
    }
    
    private var nameFr: String?
    private var nameEn: String?
    private var nameEs: String?
    private var nameDe: String?
    private var nameIt: String?
    private var nameNl: String?
    private var namePt: String?
    
    
    
    
    private var descriptionFr : String?
    private var descriptionEn : String?
    private var descriptionIt : String?
    private var descriptionEs : String?
    private var descriptionNl : String?
    private var descriptionPt : String?
    private var descriptionDe : String?
    
    
    
    private var vocalFr : String?
    private var vocalEn : String?
    private var vocalIt : String?
    private var vocalEs : String?
    private var vocalNl : String?
    private var vocalPt : String?
    private var vocalDe : String?
    
    private var questionFr: String?
    
    private var questionEn: String?
    
    private var answerFr: String?
    
    private var answerEn: String?
    
    private var instructionFr: String?
    
    private var instructionEn: String?
    
    private var indiceFr: String?
    
    private var indiceEn: String?
    
    public var imageURL: String?
    
    public var isAutoDirectionActivated: Bool
    
    public var isBloquant: Bool
    
    public var isDirectionnal: Bool
    
    public var range: Int
    
    public var coordinatesGPX: [CLLocationCoordinate2D] = []
    
    public var status: PoiStatuts = .notPlayed
    
    public var type: PoiCategory
    
    
    
    
    
    public func getVocal() -> String? {
        let language = getLanguage()
        if language == "en-US"
        {
            return vocalEn
        }
        else if language == "fr-FR"
        {
            return vocalFr
        }
        else if language == "es-ES"
        {
            return vocalEs
        }
        else if language == "it-IT"
        {
            return vocalIt
        }
        else if language == "de-DE"
        {
            return vocalDe
        }
        else if language == "nl-NL"
        {
            return vocalNl
        }
        else if language == "pt-PT"
        {
            return vocalPt
        }
        return nil
    }
    
    
    init(snapshotValue: [String: Any]) {
            let arrayDescription = snapshotValue["Description"] as? [String: String]
            descriptionEn = arrayDescription!["EN"] ?? ""
            descriptionFr = arrayDescription!["FR"] ?? ""
            let arrayName = snapshotValue["Name"] as? [String: String]
            nameEn = arrayName!["EN"] ?? ""
            nameFr = arrayName!["FR"] ?? ""
            imageURL = snapshotValue["ImageURL"] as? String ?? ""

            //let arrayMP3 = snapshotValue["arrayMP3"] as? [String: String]
            //audioURLFr = arrayMP3!["EN"] ?? ""
            //audioURLEn = arrayMP3!["FR"] ?? ""

            //let arrayTextMP3 = snapshotValue["arrayTextMP3"] as? [String: String]
            //audioTextEn = arrayTextMP3!["MP3TexteEN"] ?? ""
            //audioTextFr = arrayTextMP3!["MP3TexteFR"] ?? ""
            //status = snapshotValue["Status"] as? Int ?? 0
            let typeInt = snapshotValue["IdType"] as? Int ?? 0
            type = PoiCategory.init(rawValue: typeInt) ?? PoiCategory.init(rawValue: 0)!
            //idDestination = snapshotValue["idCity"] as? String ?? ""
            isBloquant = snapshotValue["isBloquant"] as? Bool ?? false
            isDirectionnal = snapshotValue["isDirectionnal"] as? Bool ?? false
            //audioActivated = snapshotValue["audioActivated"] as? Bool ?? false
            isAutoDirectionActivated = snapshotValue["isAutoDirectionAcivated"] as? Bool ?? true //name error is normal in acivated
            //typeDirection = snapshotValue["type"] as? Int ?? 0

            if let coordinates = snapshotValue["GPS"] as? [[String: Double]] {
                for coordinate in coordinates{
                    var latitude = coordinate["latitude"] ?? 0
                    if(latitude == 0) {
                        latitude = coordinate["Latitude"] ?? 0
                    }
                    var longitude = coordinate["longitude"] ?? 0
                    if(longitude == 0) {
                        longitude = coordinate["Longitude"] ?? 0
                    }
                    let gpx = CLLocationCoordinate2D.init(latitude: latitude, longitude: longitude)
                    coordinatesGPX.append(gpx)
                }
            }

            range = snapshotValue["Range"] as? Int ?? 10
            //ref = nil
            key = snapshotValue["id"] as? String ?? ""

    }
    
    public func getLocations() -> [CLLocation] {
        var locations = [CLLocation]()
        for coordinate in coordinatesGPX
        {
            locations.append(CLLocation.init(latitude: coordinate.latitude, longitude: coordinate.longitude))
        }
        return locations
    }
    public func getLanguage() -> String?
    {
        return MyUtils.getPoiLanguage(en: descriptionEn, fr: descriptionFr, es: descriptionEs, it: descriptionIt, de: descriptionDe, nl: descriptionNl, pt: descriptionPt)
    }
    
    public func getDescription(language:String) -> String? {
        if language == "EN"
        {
            return descriptionEn
        }
        else if language == "FR"
        {
            return descriptionFr
        }
        else if language == "ES"
        {
            return descriptionEs
        }
        else if language == "IT"
        {
            return descriptionIt
        }
        else if language == "DE"
        {
            return descriptionDe
        }
        else if language == "NL"
        {
            return descriptionNl
        }
        else if language == "PT"
        {
            return descriptionPt
        }
        return nil
    }
    
}


public enum PoiStatuts
{
    case notPlayed
    case isPlaying
    case played
    case paused
    case none
}



public enum TypeRoute : Int
{
    case walking = 1
    case run = 2
    case bike = 3
    case none = -1
}




public enum PoiCategory: Int {
    
    case undefined = 0
    case monument = 1
    case culture = 2
    case divertissement = 3
    case marchand = 4
    case ruePlaceQuartier = 5
    case religion = 6
    case nature = 7
    case eau = 8
    
    case directionnelHoraire = 9
    case directionnelAntiHoraire = 10
    
    case noAnnotation = 11
    case theme = 12
    case sport = 13
    case sponsor = 100
    
    public func image() -> String? {
        switch self {
        case .culture:
            return   "culture"
        case .divertissement:
            return   "entretainment"
        case .eau:
            return   "water"
        case .marchand:
            return   "shop"
        case .monument:
            return   "enigma"
        case .nature:
            return   "nature"
        case .religion:
            return   "religion"
        case .ruePlaceQuartier:
            return   "neighbourhood"
        case .undefined:
            return   "undefined"
        case .noAnnotation:
            //No annotation for this category
            return   "undefined"
        case .theme:
            return   "themed"
        case .sport:
            return   "workout"
        case .sponsor:
            return   "sponsor"
        case .directionnelHoraire:
            //No annotation for this category
            return nil
        case .directionnelAntiHoraire:
            //No annotation for this category
            return nil
        }
    }
    
}


//public class PointOfInterestService {
//    
//    var db : Firestore!
//    
//    
//    public init() {
//        db = Firestore.firestore()
//    }
//    
//    
//    
//    public func gePoisAndDirectionalsFireStore( route:RouteInformation,  _ callBack:@escaping (Result<[PointOfInterest]>) -> Void) {
//        
//        var index = 0
//        var pois : [PointOfInterest] = []
//        for id in route.poisId
//        {
//            db.collection("POI").document(id).getDocument { (document, error) in
//                
//                
//                
//                if let err = error {
//                    print("Error getting documents: \(err)")
//                }
//                let poi = PointOfInterest(snapshotValue: document!.data()!,key:document!.documentID )
//                if poi.statusDB == 4
//                {
//                    pois.append(poi)
//                }
//                
//                
//                index += 1
//                if index == route.poisId.count
//                {
//                    callBack(Result.success(pois))
//                }
//            }
//        }
//        
//        
//    }
//    
//    
//    
//    public func gePoisAndDirectionalsFireStore( routes:[RouteInformation],ids : [String],  _ callBack:@escaping (Result<[RouteInformation]>) -> Void) {
//        
//        
//        var currentIndex = 0
//        for (index,route) in routes.enumerated()
//        {
//            db.collection("POI").whereField("Route", arrayContains: route.key).getDocuments { (snapshot, error) in
//                
//                print(snapshot?.query)
//                var pois : [PointOfInterest] = []
//                if let err = error {
//                    print("Error getting documents: \(err)")
//                } else if let documents = snapshot?.documents
//                {
//                    
//                    for document in documents
//                    {
//                        var poi = PointOfInterest(snapshotValue: document.data(),key:document.documentID )
//                        poi.route = route
//                        if poi.statusDB == 4
//                        {
//                            pois.append(poi)
//                        }
//                        
//                    }
//                    
//                    route.pois = pois
//                    currentIndex  += 1
//                    if currentIndex  == routes.count
//                    {
//                        callBack(Result.success(routes))
//                    }
//                }
//                
//                
//            }
//            
//        }
//        
//        
//    }
//    
//    
//    
//    public func gePoisAndDirectionalsFireStore(by routes:[RouteInformation],cityId : [String],  _ callBack:@escaping (Result<[RouteInformation]>) -> Void) {
//        
//        let start = CFAbsoluteTimeGetCurrent()
//        db.collection("POI")
//            //.whereField("Routes", in: [[keyRoute:true]])
//            .whereField("IdCity", in: cityId)
//            
//            .getDocuments() { (snapshot, err) in
//                let diff = CFAbsoluteTimeGetCurrent() - start
//                print("Time = Took pois \(diff) seconds")
//                if let err = err {
//                    print("Error getting documents: \(err)")
//                } else {
//                    var pois : [PointOfInterest] = []
//                    DispatchQueue.main.asyncAfter(deadline: DispatchTime.now()) {
//                        for document in snapshot!.documents {
//                            let poi = PointOfInterest(snapshotValue: document.data(),key:document.documentID )
//                            if poi.type != .noAnnotation
//                            {
//                                if poi.statusDB == 4
//                                {
//                                    pois.append(poi)
//                                }
//                            }
//                            
//                        }
//                        for (i,route) in routes.enumerated()
//                        {
//                            routes[i].pois = pois.filter({ (p) -> Bool in
//                                return  route.poisId.contains { (id) -> Bool in
//                                    return id == p.key
//                                }
//                            })
//                        }
//                        
//                        let diff = CFAbsoluteTimeGetCurrent() - start
//                        print("Time = Took pois \(diff) seconds")
//                        callBack(Result.success(routes))
//                        
//                    }
//                    
//                }
//                
//            }
//        
//    }
//    
//    public func geAllPoisAndDirectionalsFireStore(_ callBack:@escaping (Result<[PointOfInterest]>) -> Void) {
//        
//        
//        db.collection("POI")
//            //.whereField("Routes", in: [[keyRoute:true]])
//            
//            .getDocuments() { (snapshot, err) in
//                if let err = err {
//                    print("Error getting documents: \(err)")
//                } else {
//                    var pois : [PointOfInterest] = []
//                    DispatchQueue.main.asyncAfter(deadline: DispatchTime.now()) {
//                        for document in snapshot!.documents {
//                            let poi = PointOfInterest(snapshotValue: document.data(),key:document.documentID )
//                            if poi.statusDB == 4
//                            {
//                                pois.append(poi)
//                            }
//                        }
//                        callBack(Result.success(pois))
//                    }
//                }
//            }
//    }
//}

==> v4_navigation_engine-0.1.80.tar.gz: ios/Classes/NavigationV4 (1)/Models/PointOfInterest.swift <==
//
//  PointOfInterest.swift
//  NavigationUI
//
//  Created by Hassine on 17/06/2020.
//  Copyright © 2020 com.mile. All rights reserved.
//


import Foundation
import CoreLocation
//import Firebase
//import FirebaseFirestore




public struct PointOfInterest  {
    public var statusDB: Int = 0 // status Data base
    
    
    public var route: RouteInformation?
    public var key: String
    
    
    
    public var description: String? {
        get {
            return MyUtils.translateToSelectedLanguage(en: descriptionEn, fr: descriptionFr, es: descriptionEs, it: descriptionIt, de: descriptionDe, nl: descriptionNl, pt: descriptionPt)
        }
    }
    
    public var vocal: String? {
        get {
            return MyUtils.translateToSelectedLanguage(en: vocalEn, fr: vocalFr, es: vocalEs, it: vocalIt, de: vocalDe, nl: vocalNl, pt: vocalPt)
        }
    }
    
    public  var name: String {
        get {
            return MyUtils.translateToSelectedLanguage(en: nameEn, fr: nameFr, es: nameEs, it: nameIt, de: nameDe, nl: nameNl, pt: namePt) ?? "error"
        }
    }
    
    
    public var question: String? {
        get {
            if "fr" == MyUtils.getLanguageISO()
            {
                return questionFr
            }
            else
            {
                return questionEn
            }
        }
    }
    
    public  var answer: String? {
        get {
            if "fr" == MyUtils.getLanguageISO()
            {
                return answerFr
            }
            else
            {
                return answerEn
            }
        }
    }
    
    
    public  var indice: String? {
        get {
            if "fr" == MyUtils.getLanguageISO()
            {
                return indiceFr
            }
            else
            {
                return indiceEn
            }
        }
    }
    
    
    public  var instruction: String? {
        get {
            if "fr" == MyUtils.getLanguageISO()
            {
                return instructionFr
            }
            else
            {
                return instructionEn
            }
        }
    }
    
    private var nameFr: String?
    private var nameEn: String?
    private var nameEs: String?
    private var nameDe: String?
    private var nameIt: String?
    private var nameNl: String?
    private var namePt: String?
    
    
    
    
    private var descriptionFr : String?
    private var descriptionEn : String?
    private var descriptionIt : String?
    private var descriptionEs : String?
    private var descriptionNl : String?
    private var descriptionPt : String?
    private var descriptionDe : String?
    
    
    
    private var vocalFr : String?
    private var vocalEn : String?
    private var vocalIt : String?
    private var vocalEs : String?
    private var vocalNl : String?
    private var vocalPt : String?
    private var vocalDe : String?
    
    private var questionFr: String?
    
    private var questionEn: String?
    
    private var answerFr: String?
    
    private var answerEn: String?
    
    private var instructionFr: String?
    
    private var instructionEn: String?
    
    private var indiceFr: String?
    
    private var indiceEn: String?
    
    public var imageURL: String?
    
    public var isAutoDirectionActivated: Bool
    
    public var isBloquant: Bool
    
    public var isDirectionnal: Bool
    
    public var range: Int
    
    public var coordinatesGPX: [CLLocationCoordinate2D] = []
    
    public var status: PoiStatuts = .notPlayed
    
    public var type: PoiCategory
    
    
    
    
    
    public func getVocal() -> String? {
        let language = getLanguage()
        if language == "en-US"
        {
            return vocalEn
        }
        else if language == "fr-FR"
        {
            return vocalFr
        }
        else if language == "es-ES"
        {
            return vocalEs
        }
        else if language == "it-IT"
        {
            return vocalIt
        }
        else if language == "de-DE"
        {
            return vocalDe
        }
        else if language == "nl-NL"
        {
            return vocalNl
        }
        else if language == "pt-PT"
        {
            return vocalPt
        }
        return nil
    }
    
    
    init(snapshotValue: [String: Any]) {
            let arrayDescription = snapshotValue["Description"] as? [String: String]
            descriptionEn = arrayDescription!["EN"] ?? ""
            descriptionFr = arrayDescription!["FR"] ?? ""
            let arrayName = snapshotValue["Name"] as? [String: String]
            nameEn = arrayName!["EN"] ?? ""
            nameFr = arrayName!["FR"] ?? ""
            imageURL = snapshotValue["ImageURL"] as? String ?? ""

            //let arrayMP3 = snapshotValue["arrayMP3"] as? [String: String]
            //audioURLFr = arrayMP3!["EN"] ?? ""
            //audioURLEn = arrayMP3!["FR"] ?? ""

            //let arrayTextMP3 = snapshotValue["arrayTextMP3"] as? [String: String]
            //audioTextEn = arrayTextMP3!["MP3TexteEN"] ?? ""
            //audioTextFr = arrayTextMP3!["MP3TexteFR"] ?? ""
            //status = snapshotValue["Status"] as? Int ?? 0
            let typeInt = snapshotValue["IdType"] as? Int ?? 0
            type = PoiCategory.init(rawValue: typeInt) ?? PoiCategory.init(rawValue: 0)!
            //idDestination = snapshotValue["idCity"] as? String ?? ""
            isBloquant = snapshotValue["IsBloquant"] as? Bool ?? false
            isDirectionnal = snapshotValue["IsDirectionnal"] as? Bool ?? false
            //audioActivated = snapshotValue["audioActivated"] as? Bool ?? false
            isAutoDirectionActivated = snapshotValue["isAutoDirectionAcivated"] as? Bool ?? true //name error is normal in acivated
            //typeDirection = snapshotValue["type"] as? Int ?? 0

            if let coordinates = snapshotValue["GPS"] as? [[String: Double]] {
                for coordinate in coordinates{
                    var latitude = coordinate["latitude"] ?? 0
                    if(latitude == 0) {
                        latitude = coordinate["Latitude"] ?? 0
                    }
                    var longitude = coordinate["longitude"] ?? 0
                    if(longitude == 0) {
                        longitude = coordinate["Longitude"] ?? 0
                    }
                    let gpx = CLLocationCoordinate2D.init(latitude: latitude, longitude: longitude)
                    coordinatesGPX.append(gpx)
                }
            }

            range = snapshotValue["Range"] as? Int ?? 10
            //ref = nil
            key = snapshotValue["id"] as? String ?? ""

    }
    
    public func getLocations() -> [CLLocation] {
        var locations = [CLLocation]()
        for coordinate in coordinatesGPX
        {
            locations.append(CLLocation.init(latitude: coordinate.latitude, longitude: coordinate.longitude))
        }
        return locations
    }
    public func getLanguage() -> String?
    {
        return MyUtils.getPoiLanguage(en: descriptionEn, fr: descriptionFr, es: descriptionEs, it: descriptionIt, de: descriptionDe, nl: descriptionNl, pt: descriptionPt)
    }
    
    public func getDescription(language:String) -> String? {
        if language == "EN"
        {
            return descriptionEn
        }
        else if language == "FR"
        {
            return descriptionFr
        }
        else if language == "ES"
        {
            return descriptionEs
        }
        else if language == "IT"
        {
            return descriptionIt
        }
        else if language == "DE"
        {
            return descriptionDe
        }
        else if language == "NL"
        {
            return descriptionNl
        }
        else if language == "PT"
        {
            return descriptionPt
        }
        return nil
    }
    
}


public enum PoiStatuts
{
    case notPlayed
    case isPlaying
    case played
    case paused
    case none
}



public enum TypeRoute : Int
{
    case walking = 1
    case run = 2
    case bike = 3
    case none = -1
}




public enum PoiCategory: Int {
    
    case undefined = 0
    case monument = 1
    case culture = 2
    case divertissement = 3
    case marchand = 4
    case ruePlaceQuartier = 5
    case religion = 6
    case nature = 7
    case eau = 8
    
    case directionnelHoraire = 9
    case directionnelAntiHoraire = 10
    
    case noAnnotation = 11
    case theme = 12
    case sport = 13
    case sponsor = 100
    
    public func image() -> String? {
        switch self {
        case .culture:
            return   "culture"
        case .divertissement:
            return   "entretainment"
        case .eau:
            return   "water"
        case .marchand:
            return   "shop"
        case .monument:
            return   "enigma"
        case .nature:
            return   "nature"
        case .religion:
            return   "religion"
        case .ruePlaceQuartier:
            return   "neighbourhood"
        case .undefined:
            return   "undefined"
        case .noAnnotation:
            //No annotation for this category
            return   "undefined"
        case .theme:
            return   "themed"
        case .sport:
            return   "workout"
        case .sponsor:
            return   "sponsor"
        case .directionnelHoraire:
            //No annotation for this category
            return nil
        case .directionnelAntiHoraire:
            //No annotation for this category
            return nil
        }
    }
    
}


//public class PointOfInterestService {
//    
//    var db : Firestore!
//    
//    
//    public init() {
//        db = Firestore.firestore()
//    }
//    
//    
//    
//    public func gePoisAndDirectionalsFireStore( route:RouteInformation,  _ callBack:@escaping (Result<[PointOfInterest]>) -> Void) {
//        
//        var index = 0
//        var pois : [PointOfInterest] = []
//        for id in route.poisId
//        {
//            db.collection("POI").document(id).getDocument { (document, error) in
//                
//                
//                
//                if let err = error {
//                    print("Error getting documents: \(err)")
//                }
//                let poi = PointOfInterest(snapshotValue: document!.data()!,key:document!.documentID )
//                if poi.statusDB == 4
//                {
//                    pois.append(poi)
//                }
//                
//                
//                index += 1
//                if index == route.poisId.count
//                {
//                    callBack(Result.success(pois))
//                }
//            }
//        }
//        
//        
//    }
//    
//    
//    
//    public func gePoisAndDirectionalsFireStore( routes:[RouteInformation],ids : [String],  _ callBack:@escaping (Result<[RouteInformation]>) -> Void) {
//        
//        
//        var currentIndex = 0
//        for (index,route) in routes.enumerated()
//        {
//            db.collection("POI").whereField("Route", arrayContains: route.key).getDocuments { (snapshot, error) in
//                
//                print(snapshot?.query)
//                var pois : [PointOfInterest] = []
//                if let err = error {
//                    print("Error getting documents: \(err)")
//                } else if let documents = snapshot?.documents
//                {
//                    
//                    for document in documents
//                    {
//                        var poi = PointOfInterest(snapshotValue: document.data(),key:document.documentID )
//                        poi.route = route
//                        if poi.statusDB == 4
//                        {
//                            pois.append(poi)
//                        }
//                        
//                    }
//                    
//                    route.pois = pois
//                    currentIndex  += 1
//                    if currentIndex  == routes.count
//                    {
//                        callBack(Result.success(routes))
//                    }
//                }
//                
//                
//            }
//            
//        }
//        
//        
//    }
//    
//    
//    
//    public func gePoisAndDirectionalsFireStore(by routes:[RouteInformation],cityId : [String],  _ callBack:@escaping (Result<[RouteInformation]>) -> Void) {
//        
//        let start = CFAbsoluteTimeGetCurrent()
//        db.collection("POI")
//            //.whereField("Routes", in: [[keyRoute:true]])
//            .whereField("IdCity", in: cityId)
//            
//            .getDocuments() { (snapshot, err) in
//                let diff = CFAbsoluteTimeGetCurrent() - start
//                print("Time = Took pois \(diff) seconds")
//                if let err = err {
//                    print("Error getting documents: \(err)")
//                } else {
//                    var pois : [PointOfInterest] = []
//                    DispatchQueue.main.asyncAfter(deadline: DispatchTime.now()) {
//                        for document in snapshot!.documents {
//                            let poi = PointOfInterest(snapshotValue: document.data(),key:document.documentID )
//                            if poi.type != .noAnnotation
//                            {
//                                if poi.statusDB == 4
//                                {
//                                    pois.append(poi)
//                                }
//                            }
//                            
//                        }
//                        for (i,route) in routes.enumerated()
//                        {
//                            routes[i].pois = pois.filter({ (p) -> Bool in
//                                return  route.poisId.contains { (id) -> Bool in
//                                    return id == p.key
//                                }
//                            })
//                        }
//                        
//                        let diff = CFAbsoluteTimeGetCurrent() - start
//                        print("Time = Took pois \(diff) seconds")
//                        callBack(Result.success(routes))
//                        
//                    }
//                    
//                }
//                
//            }
//        
//    }
//    
//    public func geAllPoisAndDirectionalsFireStore(_ callBack:@escaping (Result<[PointOfInterest]>) -> Void) {
//        
//        
//        db.collection("POI")
//            //.whereField("Routes", in: [[keyRoute:true]])
//            
//            .getDocuments() { (snapshot, err) in
//                if let err = err {
//                    print("Error getting documents: \(err)")
//                } else {
//                    var pois : [PointOfInterest] = []
//                    DispatchQueue.main.asyncAfter(deadline: DispatchTime.now()) {
//                        for document in snapshot!.documents {
//                            let poi = PointOfInterest(snapshotValue: document.data(),key:document.documentID )
//                            if poi.statusDB == 4
//                            {
//                                pois.append(poi)
//                            }
//                        }
//                        callBack(Result.success(pois))
//                    }
//                }
//            }
//    }
//}
